using System;
using System.Web;
using System.Web.SessionState;

/// <summary>
/// An HTTP handler that wraps another and advertises read-write
/// session state requirement via <see cref="IRequiresSessionState"/>.
/// </summary>

public sealed class SessionRequringHandler : 
    IHttpHandler, 
    IRequiresSessionState
{
    public IHttpHandler InnerHandler { get; private set; }

    public SessionRequringHandler(IHttpHandler handler)
    {
        if (handler == null) throw new ArgumentNullException("handler");
        InnerHandler = handler;
    }

    public void ProcessRequest(HttpContext context)
    {
        InnerHandler.ProcessRequest(context);
    }

    public bool IsReusable
    {
        get { return InnerHandler.IsReusable; }
    }
}